==> sirikali_1.4.1.orig.tar.xz: SiriKali-1.4.1/src/engines/ecryptfs.h <==
/*
 *
 *  Copyright (c) 2018
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "../engines.h"

struct ecryptfs : public engines::engine
{
	ecryptfs() ;

	bool requiresPolkit() const override ;

	void updateMountOptions( engines::engine::options&,
				 QString& configFilePath ) const override ;

	bool unmount( const QString& cipherFolder,
		      const QString& mountPoint,
		      int maxCount ) const override ;

	engines::engine::status errorCode( const QString& e,int s ) const override ;

	engines::engine::args command( const QString& password,
				       const engines::engine::cmdArgsList& args ) const override ;

	QString installedVersionString() const override ;

	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;

private:
	mutable bool m_unset = true ;
	mutable bool m_requirePolkit = true ;
} ;

==> sirikali_1.4.2.orig.tar.xz: SiriKali-1.4.2/src/engines/ecryptfs.h <==
/*
 *
 *  Copyright (c) 2018
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "../engines.h"

struct ecryptfs : public engines::engine
{
	ecryptfs() ;

	bool requiresPolkit() const override ;

	void updateOptions( engines::engine::options& ) const override ;

	engines::engine::status unmount( const QString& cipherFolder,
					 const QString& mountPoint,
					 int maxCount ) const override ;

	engines::engine::status errorCode( const QString& e,int s ) const override ;

	engines::engine::args command( const QByteArray& password,
				       const engines::engine::cmdArgsList& args ) const override ;

	const QString& installedVersionString() const override ;

	void GUICreateOptionsinstance( QWidget * parent,engines::engine::function ) const override ;

private:
	bool m_requirePolkit ;
	engines::version m_version ;
} ;
